@@ -5,7 +5,7 @@ use warnings;
 
 use vars qw($VERSION @ISA);
 
-$VERSION = '0.106_03';
+$VERSION = '0.106_04';
 
 use DateTime 0.08;
 @ISA = 'DateTime';
@@ -80,6 +80,10 @@ sub _ymd2rd {	## no critic (ProhibitUnusedPrivateSubroutines)
     }
 }
 
+sub calendar_name {
+    return 'Julian';
+}
+
 sub epoch {
     my $self = shift;
 
@@ -152,6 +156,10 @@ DateTime, and changes the output of one other method.
 
 =over 4
 
+=item * calendar_name
+
+Returns C<'Julian'>.
+
 =item * gregorian_deviation
 
 Returns the difference in days between the Gregorian and the Julian
